from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, String, Int, Float, Boolean

Cruxadapter_V0_1_0 = CommandToolBuilder(tool="CruxAdapter", base_command=["CruxAdapter"], inputs=[ToolInput(tag="in_in", input_type=File(optional=True), prefix="-in", doc=InputDocumentation(doc="*                            Input file (valid formats: 'mzML')")), ToolInput(tag="in_out", input_type=File(optional=True), prefix="-out", doc=InputDocumentation(doc="*                           Output file (valid formats: 'idXML')")), ToolInput(tag="in_database", input_type=File(optional=True), prefix="-database", doc=InputDocumentation(doc="*                      FASTA file (valid formats: 'FASTA')")), ToolInput(tag="in_crux_executable", input_type=String(optional=True), prefix="-crux_executable", doc=InputDocumentation(doc="*         Crux executable of the installation e.g. 'crux.exe'")), ToolInput(tag="in_extra_index_args", input_type=String(optional=True), prefix="-extra_index_args", doc=InputDocumentation(doc="Extra arguments to be passed to tide-index")), ToolInput(tag="in_extra_search_args", input_type=String(optional=True), prefix="-extra_search_args", doc=InputDocumentation(doc="Extra arguments to be passed to tide-search")), ToolInput(tag="in_extra_percolator_args", input_type=String(optional=True), prefix="-extra_percolator_args", doc=InputDocumentation(doc="Extra arguments to be passed to percolator")), ToolInput(tag="in_precursor_mass_tolerance", input_type=Int(optional=True), prefix="-precursor_mass_tolerance", doc=InputDocumentation(doc="Precursor monoisotopic mass tolerance (Crux parameter: peptide_mass_tolerance) (default: '10')")), ToolInput(tag="in_precursor_mass_units", input_type=String(optional=True), prefix="-precursor_mass_units", doc=InputDocumentation(doc="Unit of precursor mass tolerance (amu, m/z or ppm) (default: 'ppm' valid: 'mass', 'mz', 'ppm')")), ToolInput(tag="in_fragment_bin_offset", input_type=Int(optional=True), prefix="-fragment_bin_offset", doc=InputDocumentation(doc="In the discretization of the m/z axes of the observed and theoretical spectra, this parameter specifies the location of the left edge of the first bin, relative to mass = 0 (i.e., mz-bin-offset = 0.xx means the left edge of the first bin will be located at +0.xx Da). (default: '0')")), ToolInput(tag="in_fragment_bin_width", input_type=Int(optional=True), prefix="-fragment_bin_width", doc=InputDocumentation(doc="Before calculation of the XCorr score, the m/z axes of the observed and theoretical spectra are discretized. This parameter specifies the size of each bin. The exact formula for computing the discretized m/z value is floor((x/mz-bin-width) + 1.0 - mz-bin-offset), where x is the observed m/z value. For low resolution ion trap ms/ms data 1.0005079 and for high resolution ms/ms 0.02 is recommended. (default: '0.02')")), ToolInput(tag="in_isotope_error", input_type=String(optional=True), prefix="-isotope_error", doc=InputDocumentation(doc="List of positive, non-zero integers.")), ToolInput(tag="in_run_percolator", input_type=String(optional=True), prefix="-run_percolator", doc=InputDocumentation(doc="Whether to run percolator after tide-search (default: 'true' valid: 'true', 'false')")), ToolInput(tag="in_enzyme", input_type=String(optional=True), prefix="-enzyme", doc=InputDocumentation(doc="The enzyme used for peptide digestion. (default: 'trypsin' valid: 'custom-enzyme', 'trypsin', 'lys-c', 'lys-n', 'asp-n', 'arg-c', 'chymotrypsin', 'iodosobenzoate', 'staph-protease', 'proline-endopeptidase', 'glu-c', 'pepsin-a', 'elastase-trypsin-chymotrypsin', 'trypsin/p', 'cyanogen-bromide', 'clostripain', 'no-enzyme', 'elastase')")), ToolInput(tag="in_digestion", input_type=String(optional=True), prefix="-digestion", doc=InputDocumentation(doc="Full, partial or non specific digestion (default: 'full-digest' valid: 'full-digest', 'partial-digest', 'non-specific-digest')")), ToolInput(tag="in_allowed_missed_cleavages", input_type=Int(optional=True), prefix="-allowed_missed_cleavages", doc=InputDocumentation(doc="Number of possible cleavage sites missed by the enzyme, maximum value is 5; for enzyme search (default: '0')")), ToolInput(tag="in_decoy_format", input_type=String(optional=True), prefix="-decoy-format", doc=InputDocumentation(doc="Decoy generation method either by reversing the sequence or shuffling it. (default: 'shuffle' valid: 'none', 'shuffle', 'peptide-reverse', 'protein-reverse')")), ToolInput(tag="in_keep_terminal_aminos", input_type=String(optional=True), prefix="-keep-terminal-aminos", doc=InputDocumentation(doc="Whether to keep N and C terminal in place or also shuffled / reversed. (default: 'NC' valid: 'N', 'C', 'NC', 'none')")), ToolInput(tag="in_c_term_modifications", input_type=Float(optional=True), prefix="-cterm_modifications", doc=InputDocumentation(doc="Specifies C-terminal static and variable mass modifications on peptides.  Specify a comma-separated list of C-terminal modification sequences of the form: X+21.9819 Default = <empty>.")), ToolInput(tag="in_n_term_modifications", input_type=Float(optional=True), prefix="-nterm_modifications", doc=InputDocumentation(doc="Specifies N-terminal static and variable mass modifications on peptides.  Specify a comma-separated list of N-terminal modification sequences of the form: 1E-18.0106,C-17.0265 Default = <empty>.")), ToolInput(tag="in_modifications", input_type=Float(optional=True), prefix="-modifications", doc=InputDocumentation(doc="Expression for static and variable mass modifications to include. Specify a comma-separated list of modification sequences of the form: C+57.02146,2M+15.9949,1STY+79.966331,... Default = C+57.02146.")), ToolInput(tag="in_test_fdr", input_type=Float(optional=True), prefix="-test_fdr", doc=InputDocumentation(doc="False discovery rate threshold used in selecting hyperparameters during internal cross-validation and for reporting the final results. (default: '0.01')")), ToolInput(tag="in_train_fdr", input_type=Float(optional=True), prefix="-train_fdr", doc=InputDocumentation(doc="False discovery rate threshold to define positive examples in training. (default: '0.01')")), ToolInput(tag="in_ini", input_type=File(optional=True), prefix="-ini", doc=InputDocumentation(doc="Use the given TOPP INI file")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="-threads", doc=InputDocumentation(doc="Sets the number of threads allowed to be used by the TOPP tool (default: '1')")), ToolInput(tag="in_write_ini", input_type=File(optional=True), prefix="-write_ini", doc=InputDocumentation(doc="Writes the default configuration file")), ToolInput(tag="in_helphelp", input_type=Boolean(optional=True), prefix="--helphelp", doc=InputDocumentation(doc="Shows all options (including advanced)"))], outputs=[ToolOutput(tag="out_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out", type_hint=File()), doc=OutputDocumentation(doc="*                           Output file (valid formats: 'idXML')"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Cruxadapter_V0_1_0().translate("wdl", allow_empty_container=True)

